pub struct PaginatedListOptions {
pub offset: Option<String>,
pub delimiter: Option<Cow<'static, str>>,
pub max_keys: Option<usize>,
pub page_token: Option<String>,
pub extensions: Extensions,
}Expand description
Options for a paginated list request
Fields
offset: Option<String>Path to start listing from
Note: Not all stores support this
For stores that do support this, the returned result should not include the object with this key.
delimiter: Option<Cow<'static, str>>A delimiter use to group keys with a common prefix
Note: Some stores only support /
max_keys: Option<usize>The maximum number of paths to return
page_token: Option<String>A page token from a previous request
Note: Behaviour is implementation defined if the previous request used a different prefix or options
extensions: ExtensionsImplementation-specific extensions. Intended for use by implementations that need to pass context-specific information (like tracing spans) via trait methods.
These extensions are ignored entirely by backends offered through this crate.