PaginatedListStore

Trait PaginatedListStore 

pub trait PaginatedListStore:
    Send
    + Sync
    + 'static {
    // Required method
    fn list_paginated<'life0, 'life1, 'async_trait>(
        &'life0 self,
        prefix: Option<&'life1 str>,
        opts: PaginatedListOptions,
    ) -> Pin<Box<dyn Future<Output = Result<PaginatedListResult>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
A low-level interface for interacting with paginated listing APIs

Most use-cases should prefer ObjectStore::list as this is supported by more backends, including LocalFileSystem, however, PaginatedListStore can be used where stateless pagination or non-path segment based listing is required

Required Methods

fn list_paginated<'life0, 'life1, 'async_trait>( &'life0 self, prefix: Option<&'life1 str>, opts: PaginatedListOptions, ) -> Pin<Box<dyn Future<Output = Result<PaginatedListResult>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Perform a paginated list request

Note: the order of returned objects is not guaranteed and unlike ObjectStore::list a trailing delimiter is not automatically added to prefix

Implementors